package com.mortals.xhx.module.baseset.service.impl;

import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.module.hotword.model.HotwordEntity;
import com.mortals.xhx.module.hotword.model.HotwordQuery;
import com.mortals.xhx.module.hotword.service.HotwordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.baseset.dao.BasesetDao;
import com.mortals.xhx.module.baseset.model.BasesetEntity;
import com.mortals.xhx.module.baseset.service.BasesetService;
import org.springframework.util.ObjectUtils;

import java.util.Date;
import java.util.List;

/**
 * BasesetService
 * 填单服务基础设置 service实现
 *
 * @author zxfei
 * @date 2022-12-08
 */
@Service("basesetService")
public class BasesetServiceImpl extends AbstractCRUDServiceImpl<BasesetDao, BasesetEntity, Long> implements BasesetService {

    @Autowired
    private HotwordService hotwordService;


    @Override
    protected void findAfter(BasesetEntity params, PageInfo pageInfo, Context context, List<BasesetEntity> list) throws AppException {
        list.forEach(item -> {
            List<HotwordEntity> hotwordEntities = hotwordService.find(new HotwordQuery().siteId(item.getSiteId()));
            item.setHotwordList(hotwordEntities);
        });
        super.findAfter(params, pageInfo, context, list);
    }

    @Override
    protected void saveAfter(BasesetEntity entity, Context context) throws AppException {
        if(!ObjectUtils.isEmpty(entity.getHotwordList())){
            //更新新增热门词汇
            entity.getHotwordList().forEach(item -> {
                HotwordEntity hotwordEntity = hotwordService.selectOne(new HotwordQuery().siteId(item.getSiteId()).hotwords(item.getHotwords()));
                if (!ObjectUtils.isEmpty(hotwordEntity)) {
                    item.setId(hotwordEntity.getId());
                    item.setSearchCount(hotwordEntity.getSearchCount());
                    item.setUpdateTime(new Date());
                    hotwordService.update(item,context);
                }else{
                    item.setCreateUserId(this.getContextUserId(context));
                    item.setCreateTime(new Date());
                    hotwordService.save(item,context);
                }
            });
        }



        super.saveAfter(entity, context);
    }
}